summaryrefslogtreecommitdiff
path: root/lib/isnan.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/isnan.c')
-rw-r--r--lib/isnan.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/isnan.c b/lib/isnan.c
index a59dea792..ad96c1f56 100644
--- a/lib/isnan.c
+++ b/lib/isnan.c
@@ -117,8 +117,9 @@ FUNC (DOUBLE x)
# else
/* Be careful to not do any floating-point operation on x, such as x == x,
because x may be a signaling NaN. */
-# if defined __SUNPRO_C || defined __DECC || (defined __sgi && !defined __GNUC__)
- /* The Sun C 5.0 compilers and the Compaq (ex-DEC) 6.4 compilers don't
+# if defined __TINYC__ || defined __SUNPRO_C || defined __DECC \
+ || (defined __sgi && !defined __GNUC__) || defined __ICC
+ /* The Sun C 5.0, Intel ICC 10.0, and Compaq (ex-DEC) 6.4 compilers don't
recognize the initializers as constant expressions. The latter compiler
also fails when constant-folding 0.0 / 0.0 even when constant-folding is
not required. The SGI MIPSpro C compiler complains about "floating-point